==> signal_hound_sdk_10_07_25.zip: signal_hound_sdk/device_apis/pcr_series/docs/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PCR4200 API", "index.html", [
    [ "PCR4200 API Reference", "index.html", [
      [ "Examples", "index.html#autotoc_md0", null ],
      [ "Build/Version Notes", "index.html#autotoc_md1", null ],
      [ "PC Requirements", "index.html#autotoc_md2", [
        [ "Windows Development Requirements", "index.html#autotoc_md3", null ],
        [ "Linux Development Requirements", "index.html#autotoc_md4", null ],
        [ "Other Requirements", "index.html#autotoc_md5", null ]
      ] ],
      [ "Theory of Operation", "index.html#theoryOfOperation", [
        [ "Networking", "index.html#pcrNetworking", null ],
        [ "Basic API Usage", "index.html#basicAPIUsage", null ]
      ] ],
      [ "I/Q Streaming", "index.html#iqStreaming", [
        [ "Phase Coherence and the Shared LO", "index.html#phaseCoherence", null ],
        [ "I/Q Streaming Mode", "index.html#iqStreamingMode", [
          [ "Local Streaming Mode", "index.html#localStreamingMode", null ],
          [ "Vita49 Streaming Mode", "index.html#vrtStreamingMode", null ]
        ] ],
        [ "I/Q Sample Rates", "index.html#iqSampleRates", null ],
        [ "I/Q Data Types", "index.html#iqDataTypes", [
          [ "Converting From Full Scale to Corrected I/Q", "index.html#iqConversions", null ]
        ] ],
        [ "External Triggering", "index.html#externalTriggers", null ]
      ] ],
      [ "Phase Offset and Delay Calibration", "index.html#phaseCalibration", [
        [ "Temperature Stability", "index.html#autotoc_md6", null ]
      ] ],
      [ "Sweeping", "index.html#sweeping", [
        [ "Sweep Format", "index.html#autotoc_md7", null ],
        [ "Synchronous vs. Asynchronous Sweep Acquisition", "index.html#autotoc_md8", null ]
      ] ],
      [ "VSG", "index.html#vsg", null ],
      [ "Reference Level and Sensitivity", "index.html#refLevelAndSensitivity", null ],
      [ "GPS and I/Q Timestamping", "index.html#gps", [
        [ "GPS State Machine", "index.html#gpsStateMachine", null ],
        [ "Acquiring GPS Lock", "index.html#gpsLock", null ],
        [ "I/Q Time Stamping", "index.html#IQTimestamping", [
          [ "I/Q Time Stamping Using the Internal GPS", "index.html#IQTimestampingInternal", null ],
          [ "Time Stamping Using an External GPS", "index.html#IQTimestampingExternal", null ]
        ] ],
        [ "GPS Disciplining", "index.html#gpsDisciplining", [
          [ "Automatic GPS Timebase Discipline", "index.html#autoGPSTimebaseDiscipline", null ]
        ] ],
        [ "Writing Messages to the GPS", "index.html#writingToGPS", null ]
      ] ],
      [ "Fan Control", "index.html#fanControl", null ],
      [ "Low Power State", "index.html#lowPowerMode", null ],
      [ "Multi-Receiver Operation", "index.html#multiReceiver", [
        [ "Hardware Configuration", "index.html#autotoc_md9", null ]
      ] ],
      [ "Thread Safety", "index.html#threadSafety", null ],
      [ "Multiple Processes", "index.html#autotoc_md10", null ],
      [ "Linux Notes", "index.html#linuxNotes", [
        [ "Network Throughput", "index.html#autotoc_md11", null ],
        [ "Network Devices", "index.html#autotoc_md12", null ]
      ] ],
      [ "Programming Languages Compatibility", "index.html#autotoc_md13", null ],
      [ "Estimating Sweep Size", "index.html#autotoc_md14", null ],
      [ "Window Functions", "index.html#windowFunctions", null ],
      [ "Contact Information", "index.html#autotoc_md15", null ]
    ] ],
    [ "PCR4200 Vita49 Data Format", "iq_v_r_t.html", [
      [ "Signal Data Packets", "iq_v_r_t.html#autotoc_md16", [
        [ "Signal Data Header", "iq_v_r_t.html#autotoc_md17", null ],
        [ "Stream Identifier", "iq_v_r_t.html#autotoc_md18", null ],
        [ "Integer-seconds Timestamp", "iq_v_r_t.html#autotoc_md19", null ],
        [ "Fractional-seconds Timestamp", "iq_v_r_t.html#autotoc_md20", null ],
        [ "IF Data Payload", "iq_v_r_t.html#autotoc_md21", null ],
        [ "High Rate Trigger", "iq_v_r_t.html#vrtTriggerFormat", null ],
        [ "Trailer", "iq_v_r_t.html#autotoc_md22", null ],
        [ "Indicator Bits", "iq_v_r_t.html#autotoc_md23", null ]
      ] ],
      [ "Context Packet", "iq_v_r_t.html#autotoc_md24", [
        [ "Header", "iq_v_r_t.html#autotoc_md25", null ],
        [ "Timestamping in the Context Packet", "iq_v_r_t.html#autotoc_md26", null ],
        [ "Context Section", "iq_v_r_t.html#autotoc_md27", null ],
        [ "Context Field Change Indicator", "iq_v_r_t.html#autotoc_md28", null ],
        [ "Bandwidth Field", "iq_v_r_t.html#autotoc_md29", null ],
        [ "RF Reference Frequency Field", "iq_v_r_t.html#autotoc_md30", null ],
        [ "Reference Level Field", "iq_v_r_t.html#autotoc_md31", null ],
        [ "Gain/Attenuation Field", "iq_v_r_t.html#autotoc_md32", null ],
        [ "Sample Rate Field", "iq_v_r_t.html#autotoc_md33", null ],
        [ "Temperature Field", "iq_v_r_t.html#autotoc_md34", null ],
        [ "Device Identifier Field", "iq_v_r_t.html#autotoc_md35", null ],
        [ "Formatted GPS Geolocation Field", "iq_v_r_t.html#autotoc_md36", null ],
        [ "Frequency Format", "iq_v_r_t.html#frequencyFormat", null ]
      ] ],
      [ "Calculating I/Q Data Magnitude", "iq_v_r_t.html#calculatingIQDataMagnitude", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"pcr__api_8h.html#aedc2ec1eb7dc655611038c9fd7936af3"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> signal_hound_sdk_11_11_25.zip: signal_hound_sdk/device_apis/pcr_series/docs/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "PCR4200 API", "index.html", [
    [ "PCR4200 API Reference", "index.html", [
      [ "Examples", "index.html#autotoc_md0", null ],
      [ "Build/Version Notes", "index.html#autotoc_md1", null ],
      [ "PC Requirements", "index.html#autotoc_md2", [
        [ "Windows Development Requirements", "index.html#autotoc_md3", null ],
        [ "Linux Development Requirements", "index.html#autotoc_md4", null ],
        [ "Other Requirements", "index.html#autotoc_md5", null ]
      ] ],
      [ "Theory of Operation", "index.html#theoryOfOperation", [
        [ "Networking", "index.html#pcrNetworking", null ],
        [ "Basic API Usage", "index.html#basicAPIUsage", null ]
      ] ],
      [ "I/Q Streaming", "index.html#iqStreaming", [
        [ "Phase Coherence and the Shared LO", "index.html#phaseCoherence", null ],
        [ "I/Q Streaming Mode", "index.html#iqStreamingMode", [
          [ "Local Streaming Mode", "index.html#localStreamingMode", null ],
          [ "Vita49 Streaming Mode", "index.html#vrtStreamingMode", null ]
        ] ],
        [ "I/Q Sample Rates", "index.html#iqSampleRates", null ],
        [ "I/Q Data Types", "index.html#iqDataTypes", [
          [ "Converting From Full Scale to Corrected I/Q", "index.html#iqConversions", null ]
        ] ],
        [ "External Triggering", "index.html#externalTriggers", null ],
        [ "Fast Retuning", "index.html#fastRetuning", [
          [ "Fast Retune Example", "index.html#autotoc_md6", null ]
        ] ]
      ] ],
      [ "Phase Offset and Delay Calibration", "index.html#phaseCalibration", [
        [ "Temperature Stability", "index.html#autotoc_md7", null ]
      ] ],
      [ "Sweeping", "index.html#sweeping", [
        [ "Sweep Format", "index.html#autotoc_md8", null ],
        [ "Synchronous vs. Asynchronous Sweep Acquisition", "index.html#autotoc_md9", null ]
      ] ],
      [ "VSG", "index.html#vsg", null ],
      [ "Reference Level and Sensitivity", "index.html#refLevelAndSensitivity", null ],
      [ "GPS and I/Q Timestamping", "index.html#gps", [
        [ "GPS State Machine", "index.html#gpsStateMachine", null ],
        [ "Acquiring GPS Lock", "index.html#gpsLock", null ],
        [ "I/Q Time Stamping", "index.html#IQTimestamping", [
          [ "I/Q Time Stamping Using the Internal GPS", "index.html#IQTimestampingInternal", null ],
          [ "Time Stamping Using an External GPS", "index.html#IQTimestampingExternal", null ]
        ] ],
        [ "GPS Disciplining", "index.html#gpsDisciplining", [
          [ "Automatic GPS Timebase Discipline", "index.html#autoGPSTimebaseDiscipline", null ]
        ] ],
        [ "Writing Messages to the GPS", "index.html#writingToGPS", null ]
      ] ],
      [ "Fan Control", "index.html#fanControl", null ],
      [ "Low Power State", "index.html#lowPowerMode", null ],
      [ "Multi-Receiver Operation", "index.html#multiReceiver", [
        [ "Hardware Configuration", "index.html#autotoc_md10", null ]
      ] ],
      [ "Thread Safety", "index.html#threadSafety", null ],
      [ "Multiple Processes", "index.html#autotoc_md11", null ],
      [ "Linux Notes", "index.html#linuxNotes", [
        [ "Network Throughput", "index.html#autotoc_md12", null ],
        [ "Network Devices", "index.html#autotoc_md13", null ]
      ] ],
      [ "Programming Languages Compatibility", "index.html#autotoc_md14", null ],
      [ "Estimating Sweep Size", "index.html#autotoc_md15", null ],
      [ "Window Functions", "index.html#windowFunctions", null ],
      [ "Contact Information", "index.html#autotoc_md16", null ]
    ] ],
    [ "PCR4200 Vita49 Data Format", "iq_v_r_t.html", [
      [ "Signal Data Packets", "iq_v_r_t.html#autotoc_md17", [
        [ "Signal Data Header", "iq_v_r_t.html#autotoc_md18", null ],
        [ "Stream Identifier", "iq_v_r_t.html#autotoc_md19", null ],
        [ "Integer-seconds Timestamp", "iq_v_r_t.html#autotoc_md20", null ],
        [ "Fractional-seconds Timestamp", "iq_v_r_t.html#autotoc_md21", null ],
        [ "IF Data Payload", "iq_v_r_t.html#autotoc_md22", null ],
        [ "High Rate Trigger", "iq_v_r_t.html#vrtTriggerFormat", null ],
        [ "Trailer", "iq_v_r_t.html#autotoc_md23", null ],
        [ "Indicator Bits", "iq_v_r_t.html#autotoc_md24", null ]
      ] ],
      [ "Context Packet", "iq_v_r_t.html#autotoc_md25", [
        [ "Header", "iq_v_r_t.html#autotoc_md26", null ],
        [ "Timestamping in the Context Packet", "iq_v_r_t.html#autotoc_md27", null ],
        [ "Context Section", "iq_v_r_t.html#autotoc_md28", null ],
        [ "Context Field Change Indicator", "iq_v_r_t.html#autotoc_md29", null ],
        [ "Bandwidth Field", "iq_v_r_t.html#autotoc_md30", null ],
        [ "RF Reference Frequency Field", "iq_v_r_t.html#autotoc_md31", null ],
        [ "Reference Level Field", "iq_v_r_t.html#autotoc_md32", null ],
        [ "Gain/Attenuation Field", "iq_v_r_t.html#autotoc_md33", null ],
        [ "Sample Rate Field", "iq_v_r_t.html#autotoc_md34", null ],
        [ "Temperature Field", "iq_v_r_t.html#autotoc_md35", null ],
        [ "Device Identifier Field", "iq_v_r_t.html#autotoc_md36", null ],
        [ "Formatted GPS Geolocation Field", "iq_v_r_t.html#autotoc_md37", null ],
        [ "Frequency Format", "iq_v_r_t.html#frequencyFormat", null ]
      ] ],
      [ "Calculating I/Q Data Magnitude", "iq_v_r_t.html#calculatingIQDataMagnitude", null ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Functions", "globals_func.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"pcr__api_8h.html#addc2cfbae52a392fa097e3ddf0f4bf5c"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
